## Version 0.2.2

This release includes several updates and improvements to the project.

### New Features

- Added support for passing keyword arguments to the `simple` and `querybot` functions. (d88862b) (Rena Lu)
- Updated the import statement for `llama_index` to improve code readability. (6f48ccd) (Rena Lu)
- Updated the `llama_index` requirement to the latest version. (4bc1078) (Rena Lu)
- Added a newline at the end of the v0.2.1 release notes document to maintain consistency and proper formatting in markdown files. (48ee571) (Eric Ma)

### Bug Fixes

- Removed a test print statement that was accidentally left in the code. (9b85753) (Rena Lu)

### Deprecations

- None in this release.

Note: A code style update was also made in this release, but it does not introduce any new features or bug fixes. (e3f6211) (Rena Lu)
